@@ -10,7 +10,7 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 our $pager;
 
 sub DBVERSION { 1 }
@@ -312,11 +312,10 @@ sub new_cmd {
 sub dispatch {
     my $self  = shift;
     my $class = shift;
-    my $ref   = shift || {};
 
     Carp::croak($@) unless eval "require $class;";
 
-    return $class->new( %$self, %$ref )->run;
+    return $class->new( %$self, @_ )->run;
 }
 
 # Run user defined aliases
@@ -773,11 +772,14 @@ sub get_node {
             select => [
                 'n.id AS id',
                 'n.kind AS kind',
+                't.tkind AS tkind',
                 'n.uuid AS uuid',
                 'n.first_change_id AS first_change_id',
             ],
-            from  => 'nodes n',
-            where => { 'n.id' => $token },
+            from      => 'nodes n',
+            left_join => 'topics t',
+            on        => 't.id = n.id',
+            where     => { 'n.id' => $token },
         );
 
         return $self->err( 'WrongKind', 'node (%s) is not a %s: %d',
@@ -804,10 +806,13 @@ sub current_work {
             'n.path AS path',
             'wb.start AS start',
             'wb.billable AS billable',
+            'COALESCE(t.title,"") AS title',
         ],
         from       => 'work_buffers wb',
         inner_join => 'nodes n',
         on         => 'n.id = wb.node_id',
+        left_join  => 'topics t',
+        on         => 't.id = n.id',
         where      => { 'wb.stop' => undef },
     );
 }
@@ -924,7 +929,7 @@ sub stop_work {
     }
 }
 
-sub save_work {
+sub record_work {
     my $self = shift;
     my $args = {@_};
 
@@ -1138,7 +1143,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
@@ -1305,11 +1310,10 @@ cases such as when the repository is not found.
 Loads C<$class> and creates a new object from that class populated with
 the attributes from C<$self> plus the attributes in the C<%attrs> HASH.
 
-=item dispatch($class, $attrs)
+=item dispatch($class, @args)
 
 Loads the bif class C<$class>, creates a new object populated with the
-attributes from C<$self> plus the attributes in the HASHref C<$attrs>
-and runs the C<run()> method.
+attributes from C<$self> plus C<@args> and calls the C<run()> method.
 
 =item run
 
@@ -1389,6 +1393,8 @@ reference containg the following keys:
 
 =item * kind - the type of the node
 
+=item * tkind - the topic type (for topic nodes)
+
 =item * uuid - the universally unique identifier of the node
 
 =back
@@ -1409,6 +1415,8 @@ Returns a hashref representing the currently open work buffer:
 
 =item * billable
 
+=item * title - value from topics.title if the node kind is a topic
+
 =back
 
 =item start_work(%opts)
