@@ -1,6 +1,6 @@
 package App::bif::OptArgs;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 
 package    # do a little hiding
   App::bif;
@@ -110,6 +110,12 @@ arg item => (
     isa      => 'SubCmd',
     required => 1,
     comment  => '',
+    fallback => {
+        name    => 'type',
+        isa     => 'ArrayRef',
+        comment => 'create a new topic of type TYPE',
+        greedy  => 1,
+    },
 );
 
 opt author => (
@@ -234,32 +240,6 @@ opt shortname => (
     comment => 'identity initials or short name',
 );
 
-# ------------------------------------------------------------------------
-# bif new issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/new issue/],
-    comment => 'define a problem to be solved',
-);
-
-arg title => (
-    isa     => 'Str',
-    comment => 'summary of the issue description',
-    greedy  => 1,
-);
-
-opt path => (
-    isa     => 'Str',
-    alias   => 'p',
-    comment => 'path of the containing project',
-);
-
-opt status => (
-    isa     => 'Str',
-    alias   => 's',
-    comment => 'Initial status for the task',
-);
-
 # ------------------------------------------------------------------------
 # bif new project
 # ------------------------------------------------------------------------
@@ -306,20 +286,25 @@ opt tasks => (
 );
 
 # ------------------------------------------------------------------------
-# bif new task
+# bif new topic
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/new task/],
-    comment => 'define an item of work',
+    cmd     => [qw/new topic/],
+    comment => 'define a topic of discussion',
+);
+
+arg type => (
+    isa     => 'Str',
+    comment => 'type of topic',
 );
 
 arg title => (
     isa     => 'Str',
-    comment => 'summary of the task description',
+    comment => 'summary of the topic description',
     greedy  => 1,
 );
 
-opt path => (
+opt project => (
     isa     => 'Str',
     alias   => 'p',
     comment => 'path of the containing project',
@@ -328,7 +313,7 @@ opt path => (
 opt status => (
     isa     => 'Str',
     alias   => 's',
-    comment => 'Initial status for the task',
+    comment => 'Initial status for the topic',
 );
 
 # ------------------------------------------------------------------------
@@ -372,6 +357,15 @@ subcmd(
     comment => 'list entities (contacts)',
 );
 
+# ------------------------------------------------------------------------
+# list functions
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/list functions/],
+    hidden  => 1,
+    comment => 'list database functions/tables',
+);
+
 # ------------------------------------------------------------------------
 # list hosts
 # ------------------------------------------------------------------------
@@ -396,40 +390,6 @@ subcmd(
     comment => 'list identities (contacts)',
 );
 
-# ------------------------------------------------------------------------
-# bif list issue-status
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/list task-status/],
-    comment => 'list valid status for tasks',
-);
-
-arg path => (
-    isa      => 'Str',
-    comment  => 'the path of a project',
-    required => 1,
-);
-
-# ------------------------------------------------------------------------
-# bif list issues
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/list issues/],
-    comment => 'list issues grouped by project',
-);
-
-opt status => (
-    isa     => 'Str',
-    alias   => 's',
-    comment => 'limit issues to a specific status',
-);
-
-opt project_status => (
-    isa     => 'Str',
-    alias   => 'P',
-    comment => 'limit projects by a particular project status',
-);
-
 # ------------------------------------------------------------------------
 # list plans
 # ------------------------------------------------------------------------
@@ -439,7 +399,7 @@ subcmd(
 );
 
 # ------------------------------------------------------------------------
-# bif list project-topic
+# bif list topics
 # ------------------------------------------------------------------------
 subcmd(
     cmd     => [qw/list topics/],
@@ -510,34 +470,14 @@ subcmd(
 );
 
 # ------------------------------------------------------------------------
-# bif list tasks
+# bif list topic-types
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/list tasks/],
-    comment => 'list tasks grouped by project',
+    cmd     => [qw/list topic-types/],
+    comment => 'list valid type and status for topics',
 );
 
-opt status => (
-    isa     => 'Str',
-    alias   => 's',
-    comment => 'limit tasks to a specific status',
-);
-
-opt project_status => (
-    isa     => 'Str',
-    alias   => 'P',
-    comment => 'limit projects by a particular project status',
-);
-
-# ------------------------------------------------------------------------
-# bif list task-status
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/list issue-status/],
-    comment => 'list valid status for issues',
-);
-
-arg path => (
+arg project => (
     isa      => 'Str',
     comment  => 'the path of a project',
     required => 1,
@@ -562,10 +502,10 @@ arg item => (
     },
 );
 
-opt uuid => (
+opt log => (
     isa     => 'Bool',
-    alias   => 'U',
-    comment => 'treat ID as a UUID',
+    comment => 'include bif-log output',
+    alias   => 'l',
 );
 
 opt full => (
@@ -574,6 +514,12 @@ opt full => (
     alias   => 'f',
 );
 
+opt uuid => (
+    isa     => 'Bool',
+    alias   => 'U',
+    comment => 'treat ID as a UUID',
+);
+
 # ------------------------------------------------------------------------
 # bif show entity
 # ------------------------------------------------------------------------
@@ -616,20 +562,6 @@ arg name => (
     required => 1,
 );
 
-# ------------------------------------------------------------------------
-# bif show issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/show issue/],
-    comment => 'summarize the current status of a issue',
-);
-
-arg id => (
-    isa      => 'Int',
-    comment  => 'issue ID',
-    required => 1,
-);
-
 # ------------------------------------------------------------------------
 # show plan
 # ------------------------------------------------------------------------
@@ -673,16 +605,16 @@ arg name => (
 );
 
 # ------------------------------------------------------------------------
-# bif show task
+# bif show topic
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/show task/],
-    comment => 'summarize the current status of a task',
+    cmd     => [qw/show topic/],
+    comment => 'summarize the current status of a topic',
 );
 
 arg id => (
     isa      => 'Int',
-    comment  => 'task ID',
+    comment  => 'topic ID',
     required => 1,
 );
 
@@ -855,20 +787,6 @@ arg name => (
     required => 1,
 );
 
-# ------------------------------------------------------------------------
-# bif log issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/log issue/],
-    comment => 'review history of an issue',
-);
-
-arg id => (
-    isa      => 'Str',
-    comment  => 'issue ID',
-    required => 1,
-);
-
 # ------------------------------------------------------------------------
 # bif log project
 # ------------------------------------------------------------------------
@@ -884,16 +802,16 @@ arg path => (
 );
 
 # ------------------------------------------------------------------------
-# bif log task
+# bif log topic
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/log task/],
-    comment => 'review history of a task',
+    cmd     => [qw/log topic/],
+    comment => 'review history of a topic',
 );
 
 arg id => (
     isa      => 'Str',
-    comment  => 'task ID',
+    comment  => 'topic ID',
     required => 1,
 );
 
@@ -916,6 +834,11 @@ arg id => (
     },
 );
 
+arg status => (
+    isa     => 'Str',
+    comment => 'topic STATUS',
+);
+
 opt uuid => (
     isa     => 'Bool',
     alias   => 'U',
@@ -1018,31 +941,6 @@ opt title => (
     comment => 'hub title'
 );
 
-# ------------------------------------------------------------------------
-# bif update issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/update issue/],
-    comment => 'update an issue',
-);
-
-arg id => (
-    isa      => 'Int',
-    required => 1,
-    comment  => 'issue ID',
-);
-
-arg status => (
-    isa     => 'Str',
-    comment => 'topic status',
-);
-
-opt title => (
-    isa     => 'Str',
-    alias   => 't',
-    comment => 'Title',
-);
-
 # ------------------------------------------------------------------------
 # bif update project
 # ------------------------------------------------------------------------
@@ -1069,17 +967,17 @@ opt title => (
 );
 
 # ------------------------------------------------------------------------
-# bif update task
+# bif update topic
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/update task/],
-    comment => 'update an task',
+    cmd     => [qw/update topic/],
+    comment => 'update an topic',
 );
 
 arg id => (
     isa      => 'Int',
     required => 1,
-    comment  => 'task ID',
+    comment  => 'topic ID',
 );
 
 arg status => (
@@ -1128,20 +1026,6 @@ arg name => (
     comment  => 'hub name (TODO: or ID)',
 );
 
-# ------------------------------------------------------------------------
-# bif drop issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/drop issue/],
-    comment => 'remove an issue',
-);
-
-arg id => (
-    isa      => 'Int',
-    required => 1,
-    comment  => 'issue ID',
-);
-
 # ------------------------------------------------------------------------
 # bif drop project
 # ------------------------------------------------------------------------
@@ -1157,17 +1041,17 @@ arg path => (
 );
 
 # ------------------------------------------------------------------------
-# bif drop task
+# bif drop topic
 # ------------------------------------------------------------------------
 subcmd(
-    cmd     => [qw/drop task/],
-    comment => 'remove a task',
+    cmd     => [qw/drop topic/],
+    comment => 'remove a topic',
 );
 
 arg id => (
     isa      => 'Int',
     required => 1,
-    comment  => 'task ID',
+    comment  => 'topic ID',
 );
 
 # ------------------------------------------------------------------------
@@ -1295,10 +1179,21 @@ subcmd(
     comment => 'export topics to somewhere else',
 );
 
-arg item => (
+arg id => (
     isa      => 'SubCmd',
-    comment  => '',
     required => 1,
+    comment  => 'topic ID or project PATH',
+    fallback => {
+        name    => 'id',
+        isa     => 'Str',
+        comment => 'topic ID or project PATH',
+    },
+);
+
+arg destination => (
+    isa      => 'Str',
+    required => 1,
+    comment  => 'target PATH or location',
 );
 
 opt message => (
@@ -1328,33 +1223,6 @@ arg hosts => (
     comment  => 'provider host address(es)',
 );
 
-# ------------------------------------------------------------------------
-# bif push issue
-# ------------------------------------------------------------------------
-subcmd(
-    cmd     => [qw/push issue/],
-    comment => 'push an issue to another project',
-);
-
-arg id => (
-    isa      => 'Int',
-    required => 1,
-    comment  => 'issue ID',
-);
-
-arg path => (
-    isa      => 'ArrayRef',
-    required => 1,
-    greedy   => 1,
-    comment  => 'path(s) of the destination project(s)',
-);
-
-opt err_on_exists => (
-    isa     => 'Bool',
-    comment => 'raise an error when issue exists at destination',
-    hidden  => 1,
-);
-
 # ------------------------------------------------------------------------
 # bif push project
 # ------------------------------------------------------------------------
@@ -1382,6 +1250,33 @@ opt debug_bifsync => (
     hidden  => 1,
 );
 
+# ------------------------------------------------------------------------
+# bif push topic
+# ------------------------------------------------------------------------
+subcmd(
+    cmd     => [qw/push topic/],
+    comment => 'push a topic to another project',
+);
+
+arg id => (
+    isa      => 'Int',
+    required => 1,
+    comment  => 'topic ID',
+);
+
+arg path => (
+    isa      => 'ArrayRef',
+    required => 1,
+    greedy   => 1,
+    comment  => 'path(s) of the destination project(s)',
+);
+
+opt err_on_exists => (
+    isa     => 'Bool',
+    comment => 'raise an error when topic exists at destination',
+    hidden  => 1,
+);
+
 # ------------------------------------------------------------------------
 # signup
 # ------------------------------------------------------------------------
@@ -1577,7 +1472,7 @@ App::bif::OptArgs - bif command argument & option definitions
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
