@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use parent 'App::bif';
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 
 # TODO Work out how to yamlcheck utf8 chars
 
@@ -12,6 +12,17 @@ sub run {
     my $opts = $self->opts;
     my $db   = $self->db;
 
+    my $errors = $db->xarrayrefs( pragma => 'foreign_key_check' );
+
+    return $self->err(
+        'FK',
+        "Foreign Key errors!\n"
+          . $self->render_table(
+            ' l  r  l  r ',
+            [ 'Table', 'ID', 'Destination', 'FKIndex' ], $errors
+          )
+    ) if $errors;
+
     my $sth = $db->xprepare(
         select   => 'c.id',
         from     => 'changes c',
@@ -49,7 +60,7 @@ bif-check - check all changeset UUIDs
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
