@@ -5,7 +5,7 @@ use utf8;
 use Bif::Mo;
 use DBIx::ThinSQL qw/ qv sq case coalesce concat /;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub _invalid_status {
@@ -141,60 +141,27 @@ sub _get_data {
             left_join => sq(
                 select => [
                     'p.id',
-                    "sum(task_status.status = 'open') as open",
-                    "sum(task_status.status = 'stalled') as stalled",
-                    "sum(task_status.status = 'done') as closed",
+                    "sum(ts.status = 'open') as open",
+                    "sum(ts.status = 'stalled') as stalled",
+                    "sum(ts.status = 'done') as closed",
                 ],
                 from => 'projects p',
                 do {
                     if ( $opts->{status} ) {
-                        inner_join => 'project_status',
+                        inner_join => 'project_status ps',
                           on       => {
-                            'project_status.id'     => \'p.project_status_id',
-                            'project_status.status' => $opts->{status},
+                            'ps.id'     => \'p.project_status_id',
+                            'ps.status' => $opts->{status},
                           };
                     }
                     else {
                         ();
                     }
                 },
-                inner_join => 'task_status',
-                on         => 'task_status.project_id = p.id',
-                inner_join => 'tasks',
-                on         => 'tasks.task_status_id = task_status.id',
-                do {
-                    if ( $opts->{local} ) {
-                        ( where => 'p.local = 1' );
-                    }
-                    else {
-                        ();
-                    }
-                },
-                group_by         => 'p.id',
-                union_all_select => [
-                    'p.id',
-                    "sum(issue_status.status = 'open') as open",
-                    "sum(issue_status.status = 'stalled') as stalled",
-                    "sum(issue_status.status = 'closed') as closed",
-                ],
-                from => 'projects p',
-                do {
-                    if ( $opts->{status} ) {
-                        inner_join => 'project_status',
-                          on       => {
-                            'project_status.id'     => \'p.project_status_id',
-                            'project_status.status' => $opts->{status},
-                          },
-                          ;
-                    }
-                    else {
-                        ();
-                    }
-                },
-                inner_join => 'issue_status',
-                on         => 'issue_status.project_id = p.id',
-                inner_join => 'issues',
-                on         => 'issues.issue_status_id = issue_status.id',
+                inner_join => 'topic_status ts',
+                on         => 'ts.project_id = p.id',
+                inner_join => 'topics t',
+                on         => 't.topic_status_id = ts.id',
                 do {
                     if ( $opts->{local} ) {
                         ( where => 'p.local = 1' );
@@ -228,11 +195,11 @@ __END__
 
 =for bif-doc #list
 
-bif-list-projects - list projects with task/issue count & progress
+bif-list-projects - list projects with topic count & progress
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
