@@ -6,7 +6,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/ qv case concat coalesce sq/;
 use Time::Duration qw/concise duration/;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -55,10 +55,10 @@ sub run {
                 where => { 'b.key' => 'last_sync' },
             ),
             select => [
-                qv('task')->as('type'),
-                'tasks.id AS id',
+                't.tkind AS kind',
+                't.id AS id',
                 concat(
-                    'tasks.title',
+                    't.title',
                     case (
                         when => 'n.first_change_id > b.start',
                         then => qv( $yellow . ' [+]' . $reset ),
@@ -67,55 +67,21 @@ sub run {
                         else => qv(''),
                     )
                   )->as('title'),
-                'task_status.status',
-                "strftime('%s','now') - n.ctime",
-            ],
-            from       => 'task_status',
-            inner_join => 'tasks',
-            on         => 'tasks.task_status_id = task_status.id',
-            inner_join => 'nodes n',
-            on         => 'n.id = tasks.id',
-            left_join  => 'b',
-            on         => 'n.last_change_id BETWEEN b.start AND b.stop',
-            where      => {
-                'task_status.project_id' => $project->[0],
-                do {
-                    if ( $opts->{status} ) {
-                        ( 'task_status.status' => $opts->{status} );
-                    }
-                    else {
-                        ();
-                    }
-                },
-            },
-            union_all_select => [
-                qv('issue')->as('type'),
-                'i.id AS id',
-                concat(
-                    'i.title',
-                    case (
-                        when => 'n.first_change_id > b.start',
-                        then => qv( $yellow . ' [+]' . $reset ),
-                        when => 'b.start',
-                        then => qv( $yellow . ' [±]' . $reset ),
-                        else => qv(''),
-                    )
-                  )->as('title'),
-                'ist.status',
+                'ts.status',
                 "strftime('%s','now') - n.ctime AS age",
             ],
-            from       => 'issue_status ist',
-            inner_join => 'issues i',
-            on         => 'i.issue_status_id = ist.id',
+            from       => 'topic_status ts',
+            inner_join => 'topics t',
+            on         => 't.topic_status_id = ts.id',
             inner_join => 'nodes n',
-            on         => 'n.id = i.id',
+            on         => 'n.id = t.id',
             left_join  => 'b',
             on         => 'n.last_change_id BETWEEN b.start AND b.stop',
             where      => {
-                'ist.project_id' => $project->[0],
+                'ts.project_id' => $project->[0],
                 do {
                     if ( $opts->{status} ) {
-                        ( 'ist.status' => $opts->{status} );
+                        ( 'ts.status' => $opts->{status} );
                     }
                     else {
                         ();
@@ -165,7 +131,7 @@ bif-list-topics - list projects' tasks and issues
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
@@ -173,7 +139,8 @@ bif-list-topics - list projects' tasks and issues
 
 =head1 DESCRIPTION
 
-Lists the task and issues associated with each project.
+Lists the topics (typically tasks and issues) associated with each
+project.
 
 =head1 OPTIONS
 
