@@ -11,7 +11,7 @@ use Time::Duration qw/ago/;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -76,7 +76,7 @@ sub run_by_full {
             'COALESCE(c.author,e.name) AS author',
             "COALESCE(c.author_contact_method || ': ' || c.author_contact,"
               . "ecm.method || ': ' || ecm.mvalue) AS contact",
-            'COALESCE(iss.title, ta.title) AS title',
+            't.title AS title',
             'c.uuid AS change_uuid',
             'c.action',
             'c.mtime',
@@ -92,9 +92,6 @@ sub run_by_full {
                     then => qv( $yellow . ' [+]' . $reset ),
                     else => qv(''),
                 ),
-                qv(' '),
-                'n.path'
-
             )->as('action'),
         ],
         from       => 'changes c',
@@ -108,12 +105,10 @@ sub run_by_full {
         on         => 'i.id = c.identity_id',
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
-        left_join  => 'tasks ta',
-        on         => 'ta.id = cd.action_node_id_1',
-        left_join  => 'task_status ts',
-        on         => 'ts.id = ta.task_status_id',
-        left_join  => 'issues iss',
-        on         => 'iss.id = cd.action_node_id_1',
+        left_join  => 'topics t',
+        on         => 't.id = cd.action_node_id_1',
+        left_join  => 'topic_status ts',
+        on         => 'ts.id = t.topic_status_id',
         left_join  => 'projects p',
         on         => 'p.id = ts.project_id OR p.id = cd.action_node_id_1',
         left_join  => 'nodes n',
@@ -178,10 +173,10 @@ sub run_by_time {
         on         => 'i.id = c.identity_id',
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
-        left_join  => 'tasks t',
+        left_join  => 'topics t',
         on         => 't.id = cd.action_node_id_1',
-        left_join  => 'task_status ts',
-        on         => 'ts.id = t.task_status_id',
+        left_join  => 'topic_status ts',
+        on         => 'ts.id = t.topic_status_id',
         order_by   => [ 'mdate DESC', 'c.mtime ASC', 'c.id DESC' ],
     );
 
@@ -279,10 +274,10 @@ sub run_by_id {
         on         => 'i.id = c.identity_id',
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
-        left_join  => 'tasks t',
+        left_join  => 'topics t',
         on         => 't.id = cd.action_node_id_1',
-        left_join  => 'task_status ts',
-        on         => 'ts.id = t.task_status_id',
+        left_join  => 'topic_status ts',
+        on         => 'ts.id = t.topic_status_id',
         left_join  => 'projects p',
         on         => 'p.id = ts.project_id OR p.id = cd.action_node_id_1',
         order_by   => ['c.id DESC'],
@@ -451,6 +446,7 @@ sub log_comment {
             $row->{change_uuid},
         ),
     );
+
     push( @data, $self->header( 'Action', $row->{action} ) );
     push( @data, $self->header( 'From', $row->{author}, $row->{contact} ) );
 
@@ -498,7 +494,7 @@ bif-log - review the repository or node history
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
