@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -118,7 +118,7 @@ sub run {
                 restore => 1,
             );
 
-            $self->save_work(
+            $self->record_work(
                 node_id   => $opts->{id},
                 change_id => $opts->{change_id}
             );
@@ -147,7 +147,7 @@ bif-new-identity - create a new identity in the repository
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
