@@ -3,9 +3,9 @@ use strict;
 use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
-use DBIx::ThinSQL qw/ qv sq/;
+use DBIx::ThinSQL qw/ case qv sq/;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub dup {
@@ -102,52 +102,22 @@ sub dup {
                 },
             );
 
-            @status = $dbw->xhashrefs(
-                select => [ 'ist.status', 'ist.rank', 'ist.def' ],
-                from   => 'issue_status ist',
-                where    => { 'ist.project_id' => $dup_pinfo->{id} },
-                order_by => 'ist.rank',
-            );
-
-            foreach my $status (@status) {
-                my $sid = $dbw->nextval('nodes');
-
-                $dbw->xdo(
-                    insert_into => 'func_new_issue_status',
-                    values      => {
-                        change_id  => $opts->{change_id},
-                        id         => $sid,
-                        project_id => $opts->{id},
-                        status     => $status->{status},
-                        rank       => $status->{rank},
-                        def        => $status->{def},
-                    }
-                );
-            }
-
-            @status = $dbw->xhashrefs(
-                select => [ 'ts.status', 'ts.rank', 'ts.def' ],
-                from   => 'task_status ts',
+            $dbw->xdo(
+                insert_into => [
+                    'func_new_topic_status',
+                    qw/change_id id project_id tkind status rank def/,
+                ],
+                select => [
+                    qv( $opts->{change_id} ), 'nextval("nodes")',
+                    qv( $opts->{id} ),        'ts.tkind',
+                    'ts.status',              'ts.rank',
+                    'ts.def',
+                ],
+                from     => 'topic_status ts',
                 where    => { 'ts.project_id' => $dup_pinfo->{id} },
-                order_by => 'ts.rank',
+                order_by => [qw/ts.tkind ts.rank/]
             );
 
-            foreach my $status (@status) {
-                my $sid = $dbw->nextval('nodes');
-
-                $dbw->xdo(
-                    insert_into => 'func_new_task_status',
-                    values      => {
-                        change_id  => $opts->{change_id},
-                        id         => $sid,
-                        project_id => $opts->{id},
-                        status     => $status->{status},
-                        rank       => $status->{rank},
-                        def        => $status->{def},
-                    }
-                );
-            }
-
             $self->end_change(
                 id => $opts->{change_id},
                 action_format =>
@@ -238,50 +208,28 @@ sub new_project {
         },
     );
 
-    @status = $dbw->xhashrefs(
-        select   => [ qw/status rank def/, ],
-        from     => 'default_status',
-        where    => { kind => 'issue' },
-        order_by => 'rank',
+    $dbw->xdo(
+        insert_into => [
+            'func_new_topic_status',
+            qw/change_id id project_id tkind status rank def/,
+        ],
+        select => [
+            qv( $opts->{change_id} ),
+            'nextval("nodes")',
+            qv( $opts->{id} ),
+            'ds.kind',
+            'ds.status',
+            'ds.rank',
+            case (
+                when => 'ds.def',
+                then => 1,
+                else => 0,
+            )->as('def'),
+        ],
+        from     => 'default_status ds',
+        where    => { 'ds.kind !' => [ 'project', 'hub' ] },
+        order_by => [qw/ds.kind ds.rank/]
     );
-
-    foreach my $status (@status) {
-        my $sid = $dbw->nextval('nodes');
-        $dbw->xdo(
-            insert_into => 'func_new_issue_status',
-            values      => {
-                change_id  => $opts->{change_id},
-                id         => $sid,
-                project_id => $opts->{id},
-                status     => $status->{status},
-                rank       => $status->{rank},
-                def        => $status->{def},
-            }
-        );
-    }
-
-    @status = $dbw->xhashrefs(
-        select   => [ qw/status rank def/, ],
-        from     => 'default_status',
-        where    => { kind => 'task' },
-        order_by => 'rank',
-    );
-
-    foreach my $status (@status) {
-        my $sid = $dbw->nextval('nodes');
-        $dbw->xdo(
-            insert_into => 'func_new_task_status',
-            values      => {
-                change_id  => $opts->{change_id},
-                id         => $sid,
-                project_id => $opts->{id},
-                status     => $status->{status},
-                rank       => $status->{rank},
-                def        => $status->{def},
-            }
-        );
-    }
-
 }
 
 sub run {
@@ -365,7 +313,7 @@ sub run {
                 restore => 1,
             );
 
-            $self->save_work(
+            $self->record_work(
                 node_id   => $opts->{id},
                 change_id => $opts->{change_id}
             );
@@ -394,7 +342,7 @@ bif-new-project - create a new project
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
