@@ -2,8 +2,9 @@ package App::bif::show;
 use strict;
 use warnings;
 use Bif::Mo;
+use OptArgs 'class_optargs';
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -11,8 +12,11 @@ sub run {
     my $opts = $self->opts;
     my $info = $self->get_node( $self->uuid2id( $opts->{id} ) );
 
-    return $self->new_cmd( "App::bif::show::$info->{kind}",
-        opts => { id => $info->{id} } )->run;
+    my ( $class, $newopts ) =
+      class_optargs( 'App::bif', 'show', $info->{kind}, $info->{id},
+        { $opts->{log} ? ( log => undef ) : (), } );
+
+    return $self->dispatch( $class, opts => $newopts );
 }
 
 1;
@@ -26,7 +30,7 @@ bif-show - display a node's current status
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
@@ -51,6 +55,11 @@ A node ID or a project PATH. Required.
 
 Display a more verbose version of the current status.
 
+=item --log, -l
+
+Run the appropriate bif-log-* command after producing the summary to
+get the current status and the history all together.
+
 =item --uuid, -U
 
 Lookup the node using ID as a UUID string instead of a node integer.
