@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif::show';
 
 sub run {
@@ -36,7 +36,8 @@ sub run {
     print $self->render_table( 'l  l', [ 'Hub', $hub->{name} ], \@data, 1 );
     print "\n";
 
-    $self->new_cmd( 'App::bif::log::hub', opts => { id => $hub->{id} } )->run;
+    $self->dispatch( 'App::bif::log::hub', opts => { id => $hub->{id} } )
+      if $opts->{log};
 
     return $self->ok( 'ShowHub', \@data );
 }
@@ -52,7 +53,7 @@ bif-show-hub - display a hub's current status
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
