@@ -7,7 +7,7 @@ use Bif::Mo;
 use Coro;
 use DBIx::ThinSQL qw/qv/;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -57,13 +57,7 @@ sub run {
             eval {
                 $dbw->txn(
                     sub {
-                        $self->start_work(
-                            node_id       => $hub->{id},
-                            start         => time,
-                            start_comment => "sync",
-                            billable      => 1,
-                            save          => 1,
-                        );
+                        my $start = time;
 
                         my @status = $client->sync_hub( $hub->{id} );
 
@@ -141,9 +135,12 @@ sub run {
                             from => 'changes c',
                         );
 
-                        $self->stop_work(
-                            stop    => time,
-                            restore => 1,
+                        $self->start_work(
+                            node_id       => $hub->{id},
+                            start         => $start,
+                            start_comment => 'sync',
+                            stop          => time,
+                            billable      => 0,
                         );
 
                         return;
@@ -185,7 +182,7 @@ bif-sync -  exchange changes with hubs
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
