@@ -2,8 +2,9 @@ package App::bif::update;
 use strict;
 use warnings;
 use Bif::Mo;
+use OptArgs 'class_optargs';
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -11,14 +12,19 @@ sub run {
     my $opts = $self->opts;
     my $info = $self->get_node( $self->uuid2id( $opts->{id} ) );
 
-    return $self->new_cmd(
-        "App::bif::update::$info->{kind}",
-        opts => {
-            id      => $info->{id},
-            title   => $opts->{title},
-            message => $opts->{message}
-        }
-    )->run;
+    my ( $class, $newopts ) = class_optargs(
+        'App::bif',
+        'update',
+        $info->{kind},
+        $info->{id},
+        $opts->{status} ? $opts->{status} : (),
+        {
+            $opts->{message} ? ( message => $opts->{message} ) : (),
+            $opts->{title}   ? ( title   => $opts->{title} )   : (),
+        },
+    );
+
+    return $self->dispatch( $class, opts => $newopts );
 }
 
 1;
@@ -32,7 +38,7 @@ bif-update - change or comment a node
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
