@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_5';
+our $VERSION = '0.1.5_6';
 extends 'App::bif';
 
 sub run {
@@ -51,7 +51,7 @@ sub run {
                 restore => 1,
             );
 
-            $self->save_work(
+            $self->record_work(
                 node_id   => $info->{id},
                 change_id => $opts->{change_id}
             );
@@ -80,7 +80,7 @@ bif-update-hub - update or comment a hub
 
 =head1 VERSION
 
-0.1.5_5 (2015-08-13)
+0.1.5_6 (2015-10-20)
 
 =head1 SYNOPSIS
 
