@@ -26,7 +26,7 @@ BEGIN
         h.id,
         NEW.location
     FROM
-        topics h
+        nodes h
     WHERE
         h.uuid = NEW.uuid
     ;
