@@ -31,13 +31,13 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         i.id,
         NEW.method,
         NEW.mvalue,
         NEW.uuid
     FROM
-        topics i
+        nodes i
     WHERE
         i.uuid = NEW.identity_uuid
     ;
