@@ -33,7 +33,7 @@ BEGIN
         )
     VALUES(
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         NEW.name,
         NEW.shortname,
         NEW.contact_uuid,
